# rpa_test_zhang

[![PyPI - Version](https://img.shields.io/pypi/v/rpa-test-zhang.svg)](https://pypi.org/project/rpa-test-zhang)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/rpa-test-zhang.svg)](https://pypi.org/project/rpa-test-zhang)

-----

**Table of Contents**

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install rpa-test-zhang
```

## License

`rpa-test-zhang` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
